2025-01-09 Version: 2.2.1
- Generated python 2020-02-02 for polardbx.

2025-01-08 Version: 2.2.0
- Support API DescribeGdnInstances.
- Support API SwitchGdnMemberRole.


2025-01-02 Version: 2.1.0
- Support API DescribeSlowLogRecords.


2024-12-13 Version: 2.0.2
- Update API DescribeDBInstanceAttribute: update response param.
- Update API DescribeDBInstances: update response param.


2024-12-12 Version: 2.0.1
- Update API ModifyDBInstanceClass: add param DnStorageSpace.


2024-12-04 Version: 2.0.0
- Support API DescribeOpenBackupSet.
- Update API AllocateInstancePublicConnection: delete param AccessKeyId.
- Update API AllocateInstancePublicConnection: delete param AccessKeyId.
- Update API CreateBackup: update response param.
- Update API CreateDBInstance: add param DnStorageSpace.
- Update API CreateDBInstance: add param ExtraParams.
- Update API CreateDBInstance: add param Series.
- Update API DescribeArchiveTableList: add param Action.
- Update API DescribeBackupPolicy: update response param.
- Update API DescribeBackupSetList: update response param.
- Update API DescribeColdDataBasicInfo: add param Action.
- Update API DescribeDBInstanceAttribute: update response param.
- Update API DescribeDBInstanceTopology: add param MinuteSimple.
- Update API DescribeDBInstanceTopology: update response param.
- Update API DescribeDBInstances: add param DbVersion.
- Update API DescribeDBInstances: update param RegionId.
- Update API DescribeDBInstances: update response param.
- Update API DescribeParameterTemplates: add param EngineVersion.
- Update API DescribeParameterTemplates: update param DBInstanceId.
- Update API DescribeParameters: update response param.
- Update API DescribeScaleOutMigrateTaskList: add param RegionId.
- Update API DescribeScaleOutMigrateTaskList: delete param AccessKeyId.
- Update API DescribeScaleOutMigrateTaskList: delete param AccessKeyId.
- Update API ModifyParameter: add param ParameterGroupId.
- Update API ModifyParameter: update param Parameters.
- Update API ReleaseInstancePublicConnection: delete param AccessKeyId.
- Update API ReleaseInstancePublicConnection: delete param AccessKeyId.
- Update API ReleaseInstancePublicConnection: delete param Action.
- Update API ReleaseInstancePublicConnection: delete param OwnerAccount.
- Update API ReleaseInstancePublicConnection: delete param OwnerId.
- Update API ReleaseInstancePublicConnection: delete param ResourceOwnerAccount.
- Update API ReleaseInstancePublicConnection: delete param ResourceOwnerId.
- Update API UpdateBackupPolicy: update response param.


2024-06-19 Version: 1.0.15
- Update API CreateBackup: update response param.
- Update API CreateDBInstance: add param DnStorageSpace.
- Update API CreateDBInstance: add param Series.
- Update API DescribeArchiveTableList: add param Action.
- Update API DescribeBackupPolicy: update response param.
- Update API DescribeBackupSetList: update response param.
- Update API DescribeColdDataBasicInfo: add param Action.
- Update API DescribeDBInstanceAttribute: update response param.
- Update API DescribeDBInstanceTopology: update response param.
- Update API DescribeDBInstances: update param RegionId.
- Update API DescribeDBInstances: update response param.
- Update API DescribeScaleOutMigrateTaskList: add param RegionId.
- Update API UpdateBackupPolicy: update response param.


2023-12-21 Version: 1.0.14
- Generated python 2020-02-02 for polardbx.

2023-12-14 Version: 1.0.13
- Generated python 2020-02-02 for polardbx.

2023-11-25 Version: 1.0.12
- Generated python 2020-02-02 for polardbx.

2023-09-01 Version: 1.0.11
- Generated python 2020-02-02 for polardbx.

2022-03-25 Version: 1.0.10
- Fixed some bugs.

2022-03-16 Version: 1.0.9
- Fixed some bugs.

2022-02-08 Version: 1.0.8
- Generated python 2020-02-02 for polardbx.

2021-12-30 Version: 1.0.7
- Fixed some bugs.

2021-12-07 Version: 1.0.6
- Fixed some bugs.

2021-11-18 Version: 1.0.5
- Fixed some bugs.

2021-11-17 Version: 1.0.4
- Fixed some bugs.

2021-11-02 Version: 1.0.3
- Fix some problem.

2021-10-27 Version: 1.0.2
- Fix some problem.

2021-10-12 Version: 1.0.1
- Fix some problem.

2021-03-31 Version: 1.0.0
- Generated python 2020-02-02 for polardbx.

